package com.aucma.report.mapper;

import java.util.List;
import com.aucma.report.domain.RecordExceptionProcess;
import org.apache.ibatis.annotations.Param;

/**
 * 不合格品流程管理Mapper接口
 * 
 * @author Yinq
 * @date 2024-04-24
 */
public interface RecordExceptionProcessMapper 
{
    /**
     * 查询不合格品流程管理
     * 
     * @param objId 不合格品流程管理主键
     * @return 不合格品流程管理
     */
    public RecordExceptionProcess selectRecordExceptionProcessByObjId(Long objId);

    /**
     * 查询不合格品流程管理列表
     * 
     * @param recordExceptionProcess 不合格品流程管理
     * @return 不合格品流程管理集合
     */
    public List<RecordExceptionProcess> selectRecordExceptionProcessList(RecordExceptionProcess recordExceptionProcess);

    /**
     * 新增不合格品流程管理
     * 
     * @param recordExceptionProcess 不合格品流程管理
     * @return 结果
     */
    public int insertRecordExceptionProcess(RecordExceptionProcess recordExceptionProcess);

    /**
     * 修改不合格品流程管理
     * 
     * @param recordExceptionProcess 不合格品流程管理
     * @return 结果
     */
    public int updateRecordExceptionProcess(RecordExceptionProcess recordExceptionProcess);

    /**
     * 删除不合格品流程管理
     * 
     * @param objId 不合格品流程管理主键
     * @return 结果
     */
    public int deleteRecordExceptionProcessByObjId(Long objId);

    /**
     * 批量删除不合格品流程管理
     * 
     * @param objIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRecordExceptionProcessByObjIds(Long[] objIds);

    public String checkBoxBarcode(@Param("boxBarcode") String boxBarcode);

}
