package com.aucma.report.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.report.domain.RecordExceptionProcess;
import com.aucma.report.service.IRecordExceptionProcessService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

/**
 * 不合格品流程管理Controller
 *
 * @author Yinq
 * @date 2024-04-24
 */
@RestController
@RequestMapping("/report/exceptionProcess")
public class RecordExceptionProcessController extends BaseController {
    @Autowired
    private IRecordExceptionProcessService recordExceptionProcessService;

    /**
     * 查询不合格品流程管理列表
     */
    @PreAuthorize("@ss.hasPermi('report:exceptionProcess:list')")
    @GetMapping("/list")
    public TableDataInfo list(RecordExceptionProcess recordExceptionProcess) {
        startPage();
        List<RecordExceptionProcess> list = recordExceptionProcessService.selectRecordExceptionProcessList(recordExceptionProcess);
        return getDataTable(list);
    }

    /**
     * 导出不合格品流程管理列表
     */
    @PreAuthorize("@ss.hasPermi('report:exceptionProcess:export')")
    @Log(title = "不合格品流程管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RecordExceptionProcess recordExceptionProcess) {
        List<RecordExceptionProcess> list = recordExceptionProcessService.selectRecordExceptionProcessList(recordExceptionProcess);
        ExcelUtil<RecordExceptionProcess> util = new ExcelUtil<RecordExceptionProcess>(RecordExceptionProcess.class);
        util.exportExcel(response, list, "不合格品流程管理数据");
    }

    /**
     * 获取不合格品流程管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('report:exceptionProcess:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(recordExceptionProcessService.selectRecordExceptionProcessByObjId(objId));
    }

    /**
     * 新增不合格品流程管理
     */
//    @PreAuthorize("@ss.hasPermi('report:exceptionProcess:add')")
    @Log(title = "不合格品流程管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RecordExceptionProcess recordExceptionProcess) {

        return toAjax(recordExceptionProcessService.insertRecordExceptionProcess(recordExceptionProcess));
    }

    /**
     * 修改不合格品流程管理
     */
//    @PreAuthorize("@ss.hasPermi('report:exceptionProcess:edit')")
    @Log(title = "不合格品流程管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RecordExceptionProcess recordExceptionProcess) {
        recordExceptionProcess.setUpdatedBy(getUsername());
        recordExceptionProcess.setUpdatedTime(DateUtils.getNowDate());
        return toAjax(recordExceptionProcessService.updateRecordExceptionProcess(recordExceptionProcess));
    }

    /**
     * 删除不合格品流程管理
     */
    @PreAuthorize("@ss.hasPermi('report:exceptionProcess:remove')")
    @Log(title = "不合格品流程管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(recordExceptionProcessService.deleteRecordExceptionProcessByObjIds(objIds));
    }
}
